@@ -35,15 +35,21 @@ It should be only called by the exporter.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.11'
+__version__ = '0.12'
 
 
+import copy
 import roster_core
 
+
 class Error(roster_core.CoreError):
   pass
 
 
+class DuplicateRecordError(Error):
+  pass
+
+
 class ZoneError(Error):
   pass
 
@@ -121,6 +127,20 @@ def MakeZoneString(records, zone_origin, argument_definitions, zone_name,
   Outputs:
     string of exported zone file.
   """
+  dupe_check_records = copy.deepcopy(records)
+  for record in dupe_check_records:
+    del record['ttl']
+    del record['last_user']
+    del record['view_name']
+    if( record['target'] == '@' ):
+      record['target'] = zone_origin
+
+  for current_index, record_a in enumerate(dupe_check_records):
+    next_index = current_index + 1
+    for record_b in dupe_check_records[next_index:]:
+      if( record_a == record_b ):
+        raise DuplicateRecordError('Duplicate record: %s' % record_b)
+    
   records = FormatRecordsForZone(records, zone_origin, zone_name, view_name)
   if( not records.has_key('soa') ):
     raise ZoneError('SOA not found for zone %s' % zone_name)
