@@ -35,12 +35,13 @@ It should be only called by the importer.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.11'
+__version__ = '0.12'
 
 
 import dns.zone
 import dns.rdatatype
 from dns.exception import DNSException
+import IPy
 import roster_core
 
 
@@ -53,7 +54,8 @@ class ZoneImport(object):
   from a file using dns.zone and then use the core API to put it in 
   the database.
   """
-  def __init__(self, zone_file_name, config_file_name, user_name, view=None):
+  def __init__(self, zone_file_name, config_file_name, user_name, zone_view,
+               records_view=None):
     """Sets self.core_instance, self.zone self.domain and self.view.
 
     Inputs:
@@ -67,7 +69,8 @@ class ZoneImport(object):
     self.zone = dns.zone.from_file(zone_file_name)
     self.origin = unicode(self.zone.origin)
     self.zone_name = self.origin.strip('.')
-    self.view = view
+    self.view = records_view
+    self.zone_view = zone_view
 
   def MakeViewAndZone(self):
     """Makes view and zone.
@@ -75,14 +78,14 @@ class ZoneImport(object):
     Inputs:
       self.zone_name: unicode of zone name
     """
-    if( self.view is not None and
-        not self.core_instance.ListViews(view_name=self.view) ):
-      self.core_instance.MakeView(self.view)
+    if( self.zone_view is not None and
+        not self.core_instance.ListViews(view_name=self.zone_view) ):
+      self.core_instance.MakeView(self.zone_view)
    
     existing_zones = self.core_instance.ListZones(zone_origin=self.origin)
     if( not existing_zones ):
       self.core_instance.MakeZone(self.zone_name, u'master',
-                                  self.origin, view_name=self.view)
+                                  self.origin, view_name=self.zone_view)
     else:
       self.zone_name = existing_zones.keys()[0]
 
@@ -92,21 +95,44 @@ class ZoneImport(object):
     Outputs:
       string of cidr block
     """
-    ip_parts = self.origin.split('.in-')[0].split('.')
-    ip_parts.reverse()
-    for ip_part in ip_parts:
-      if( not ip_part.isdigit() ):
+    if( self.origin.endswith('in-addr.arpa.') ):
+      ip_parts = self.origin.split('.in-')[0].split('.')
+      ip_parts.reverse()
+      for ip_part in ip_parts:
+        if( not ip_part.isdigit() ):
+          raise Error('%s is not a reverse zone.' % self.zone_name)
+
+      cidr_block = '.'.join(ip_parts)
+      ip_octets = len(ip_parts)
+
+      if( ip_octets > 3 or ip_octets < 1 ):
         raise Error('%s is not a reverse zone.' % self.zone_name)
-    cidr_block = '.'.join(ip_parts)
-    ip_octets = len(ip_parts)
-    if( ip_octets == 1 ):
-      cidr_block = '%s/8' % cidr_block
-    elif( ip_octets == 2 ):
-      cidr_block = '%s/16' % cidr_block
-    elif( ip_octets == 3 ):
-      cidr_block = '%s/24' % cidr_block
+
+      cidr_block = '%s/%s' % (cidr_block, ip_octets * 8)
+
+    elif( self.origin.endswith('ip6.arpa.') ):
+      ip_parts = self.origin.split('.ip6')[0].split('.')
+      ip_parts.reverse()
+      ip_quartets = len(ip_parts)
+
+      for ip_part in ip_parts:
+        try:
+          int(ip_part, 16)
+        except ValueError:
+          raise Error('Invalid hexidecimal number in ipv6 origin: %s' % 
+                      self.origin)
+      # fill out the rest of the ipv6 address
+      ip_parts.extend(['0' for x in range(32-ip_quartets)])
+       
+      for x in range(1,8):
+        # Put colons every 4 quartets
+        ip_parts.insert((x*4)+(x-1), ':')
+      cidr_block = ''.join(ip_parts)
+
+      cidr_block = '%s/%s' % (cidr_block, ip_quartets * 4)
+
     else:
-      raise Error('%s is not a reverse zone.' % self.zone_name)
+        raise Error('%s is not a reverse zone.' % self.zone_name)
 
     return cidr_block
 
@@ -133,11 +159,12 @@ class ZoneImport(object):
     """
     record_count = 0
     self.MakeViewAndZone()
-    if( self.origin.endswith('in-addr.arpa.') ):
+    if( self.origin.endswith('in-addr.arpa.') or
+        self.origin.endswith('ip6.arpa.') ):
       cidr_block = self.ReverseZoneToCIDRBlock()
       self.core_instance.MakeReverseRangeZoneAssignment(self.zone_name,
                                                         cidr_block)
-
+    make_record_args_list = []
     for record_tuple in self.zone.items():
       record_target = unicode(record_tuple[0])
 
@@ -154,6 +181,12 @@ class ZoneImport(object):
             record_type = u'a'
             record_args_dict = {u'assignment_ip': unicode(record_object)}
 
+          elif( record_object.rdtype == dns.rdatatype.AAAA ):
+            record_type = u'aaaa'
+            record_args_dict = {u'assignment_ip': 
+                                    unicode(IPy.IP(str(
+                                        record_object)).strFullsize())}
+
           elif( record_object.rdtype == dns.rdatatype.CNAME ):
             record_type = u'cname'
             assignment_host = self.FixHostname(unicode(record_object))
@@ -203,9 +236,18 @@ class ZoneImport(object):
             print 'Unkown record type: %s.\n %s' % (record_object.rdtype,
                                                     record_object)
             continue
-          self.core_instance.MakeRecord(record_type, record_target,
-                                        self.zone_name, record_args_dict,
-                                        ttl=ttl, view_name=self.view)
-          record_count += 1
+
+          if( record_type == u'soa' ):
+            make_record_args_list.insert(0, (record_type, record_target,
+                                             self.zone_name, record_args_dict,
+                                             self.zone_view, ttl))
+          else:
+            make_record_args_list.append((record_type, record_target,
+                                          self.zone_name, record_args_dict,
+                                          self.view, ttl))
+
+    for make_record_args in make_record_args_list:
+      self.core_instance.MakeRecord(*make_record_args)
+      record_count += 1
 
     return record_count
